OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакты",
    "Download" : "Скачать",
    "Copy link" : "Скопировать ссылку",
    "Click to copy the link to your clipboard" : "Нажмите для копирования ссылки в буфер обмена",
    "Toggle sharing" : "Переключить общий доступ",
    "Delete" : "Удалить",
    "Rename" : "Переименовать",
    "Share with users or groups" : "Поделиться с пользователями или группами",
    "can edit" : "можно редактировать",
    "Close" : "Закрыть",
    "Enabled" : "Включено",
    "Disabled" : "Отключено",
    "Copied!" : "Скопировано!",
    "Not supported!" : "Не поддерживается!",
    "Press ⌘-C to copy." : "Нажмите ⌘-C для копирования.",
    "Press Ctrl-C to copy." : "Нажмите Ctrl-C для копирования.",
    "Address book name" : "Название адресной книги",
    "Only these special characters are allowed: -_.!?#|()" : "Допустимы только следующие специальные символы: -_.!?#|()",
    "Address book could not be created." : "Не удалось создать адресную книгу.",
    "Upload new image" : "Загрузить изображение",
    "The selected image is too big (max 1MB)" : "Выбранное изображение слишком велико (макс. 1 МБ)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Эта поврежденная карточка была исправлена. Проверьте данные и выберите «сохранить» для  сохранения изменений. ",
    "No contacts in here" : "Здесь нет контактов",
    "Name" : "имя, отчество и фамилия контакта",
    "Organization" : "Организация",
    "Title" : "Должность",
    "Add field …" : "Добавить поле…",
    "Save changes" : "Сохранить изменения",
    "Address book" : "Адресная книга",
    "Loading contacts …" : "Загрузка контактов…",
    "Import into" : "Импортировать в",
    "Importing..." : "Производится импорт…",
    "Select your addressbook" : "Выберите адресную книгу",
    "Import is disabled because no writable address book had been found." : "Возможность импорта отключена, т.к. отсутствуют адресные книги, в которые можно выполнить запись.",
    "No search result for {query}" : "По запросу {query} ничего не найдено",
    "All contacts" : "Все контакты",
    "Post office box" : "Абонентский ящик",
    "Postal code" : "Почтовый индекс",
    "City" : "Город",
    "State or province" : "Область или район",
    "Country" : "Страна",
    "Address" : "Адрес",
    "(new group)" : "(новая группа)",
    "Last name" : "Фамилия",
    "First name" : "Имя",
    "Additional names" : "Отчество",
    "Prefix" : "Префикс",
    "Suffix" : "Суффикс",
    "Importing into" : "Производится импорт в",
    "New contact" : "Новый контакт",
    "Not grouped" : "Без группы",
    "Sort by" : "Сортировать по",
    "There is no address book available to create a contact." : "Отсутствует адресная книга, в которой можно создать контакт.",
    "{addressbook} shared by {owner}" : "{addressbook} от {owner}",
    "Contact not found." : "Контакт не найден.",
    "You don't have permission to write to this addressbook." : "Недостаточно прав для записи в эту адресную книгу.",
    "Contact could not be created." : "Не удалось создать контакт.",
    "No contacts in file. Only vCard files are allowed." : "В файле нет контактов. Допустимы только файлы формата vCard.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Поддерживается только формат vCard версии 4.0 (RFC6350) или версии 3.0 (RFC2426).",
    "Contact could not be moved." : "Контакт не может быть перемещён.",
    "Contact could not be saved." : "Контакт не может быть сохранён.",
    "Waiting for the server to be ready…" : "Ожидание готовности сервера…",
    "Importing…" : "Импортируется…",
    "Display name" : "Отображаемое имя",
    "Nickname" : "Псевдоним",
    "Detailed name" : "Подробное имя",
    "Notes" : "Заметки",
    "Website" : "Сайт",
    "Federated Cloud ID" : "ID в объединении облачных хранилищ",
    "Home" : "Домашний",
    "Work" : "Рабочий",
    "Other" : "Другой",
    "Groups" : "Группы",
    "Birthday" : "День рождения",
    "Anniversary" : "Годовщина",
    "Date of death" : "Дата смерти",
    "Email" : "Эл. почта",
    "Instant messaging" : "Мгновенные сообщения",
    "Phone" : "Телефон",
    "Mobile" : "Мобильный",
    "Work mobile" : "Рабочий мобильный",
    "Fax" : "Факс",
    "Fax home" : "Факс домашний",
    "Fax work" : "Факс рабочий",
    "Pager" : "Пейджер",
    "Voice" : "Голосовая почта",
    "Car" : "Номер в авто",
    "Work pager" : "Рабочий пейджер",
    "Social network" : "Социальная сеть",
    "Relationship" : "Отношнения",
    "Specify a relationship between you and the entity represented by this vCard." : "Указать отношения между собой и этим контактом.",
    "Spouse" : "Супруг",
    "Child" : "Ребёнок",
    "Mother" : "Мать",
    "Father" : "Отец",
    "Parent" : "Родитель",
    "Brother" : "Брат",
    "Sister" : "Сестра",
    "Relative" : "Родственник",
    "Friend" : "Друг",
    "Colleague" : "Коллега",
    "Manager" : "Руководитель",
    "Assistant" : "Помощник",
    "Related" : "Связи",
    "Specify a relationship between another entity and the entity represented by this vCard." : "Указать отношение между этим и другим контактом.",
    "Contact" : "Контакт",
    "Agent" : "Агент",
    "Emergency" : "Экстренный случай",
    "Co-worker" : "Коллега",
    "Gender" : "Пол",
    "Female" : "Женщина",
    "Male" : "Мужчина",
    "Details" : "Подробно",
    "Settings" : "Настройки"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
